Class: Effective::Stamp
- Inherits:
-
ActiveRecord::Base
- Object
- ActiveRecord::Base
- Effective::Stamp
- Defined in:
- app/models/effective/stamp.rb
Instance Method Summary collapse
- #created_by_admin? ⇒ Boolean
- #mark_as_issued! ⇒ Object
- #mark_as_submitted! ⇒ Object
-
#mark_paid! ⇒ Object
This is the Admin Save and Mark Paid action.
-
#submit! ⇒ Object
Called by an application when submitted Called by a stamp wizard when submitted.
- #to_s ⇒ Object
Instance Method Details
#created_by_admin? ⇒ Boolean
81 82 83 |
# File 'app/models/effective/stamp.rb', line 81 def created_by_admin? stamp_wizard_id.blank? && applicant_id.blank? end |
#mark_as_issued! ⇒ Object
77 78 79 |
# File 'app/models/effective/stamp.rb', line 77 def mark_as_issued! issued! end |
#mark_as_submitted! ⇒ Object
73 74 75 |
# File 'app/models/effective/stamp.rb', line 73 def mark_as_submitted! submitted! end |
#mark_paid! ⇒ Object
This is the Admin Save and Mark Paid action
93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'app/models/effective/stamp.rb', line 93 def mark_paid! raise('expected an user with a membership category') unless owner && owner.try(:membership).present? category = owner.membership.categories.first assign_attributes( price: category.stamp_fee, tax_exempt: category.stamp_fee_tax_exempt, qb_item_name: category.stamp_fee_qb_item_name ) submitted! Effective::Order.new(items: self, user: owner).mark_as_purchased! end |
#submit! ⇒ Object
Called by an application when submitted Called by a stamp wizard when submitted
87 88 89 90 |
# File 'app/models/effective/stamp.rb', line 87 def submit! raise('expected a purchased order') unless (purchased? || applicant&.submit_order&.purchased?) submitted! end |
#to_s ⇒ Object
69 70 71 |
# File 'app/models/effective/stamp.rb', line 69 def to_s [model_name.human, *name.presence].join(' ') end |